using System;
using System.IO;

namespace IllusionPlugin
{
	public static class ModPrefs
	{
		private static IniFile _instance;

		private static IniFile Instance
		{
			get
			{
				if (ModPrefs._instance == null)
				{
					ModPrefs._instance = new IniFile(Path.Combine(Environment.CurrentDirectory, "UserData/modprefs.ini"));
				}
				return ModPrefs._instance;
			}
		}

		public static string GetString(string section, string name, string defaultValue = "", bool autoSave = false)
		{
			string text = ModPrefs.Instance.IniReadValue(section, name);
			string result;
			if (text != "")
			{
				result = text;
			}
			else
			{
				if (autoSave)
				{
					ModPrefs.SetString(section, name, defaultValue);
				}
				result = defaultValue;
			}
			return result;
		}

		public static int GetInt(string section, string name, int defaultValue = 0, bool autoSave = false)
		{
			int num;
			int result;
			if (int.TryParse(ModPrefs.Instance.IniReadValue(section, name), out num))
			{
				result = num;
			}
			else
			{
				if (autoSave)
				{
					ModPrefs.SetInt(section, name, defaultValue);
				}
				result = defaultValue;
			}
			return result;
		}

		public static float GetFloat(string section, string name, float defaultValue = 0f, bool autoSave = false)
		{
			float num;
			float result;
			if (float.TryParse(ModPrefs.Instance.IniReadValue(section, name), out num))
			{
				result = num;
			}
			else
			{
				if (autoSave)
				{
					ModPrefs.SetFloat(section, name, defaultValue);
				}
				result = defaultValue;
			}
			return result;
		}

		public static bool GetBool(string section, string name, bool defaultValue = false, bool autoSave = false)
		{
			string @string = ModPrefs.GetString(section, name, null, false);
			bool result;
			if (@string == "1" || @string == "0")
			{
				result = (@string == "1");
			}
			else
			{
				if (autoSave)
				{
					ModPrefs.SetBool(section, name, defaultValue);
				}
				result = defaultValue;
			}
			return result;
		}

		public static bool HasKey(string section, string name)
		{
			return ModPrefs.Instance.IniReadValue(section, name) != null;
		}

		public static void SetFloat(string section, string name, float value)
		{
			ModPrefs.Instance.IniWriteValue(section, name, value.ToString());
		}

		public static void SetInt(string section, string name, int value)
		{
			ModPrefs.Instance.IniWriteValue(section, name, value.ToString());
		}

		public static void SetString(string section, string name, string value)
		{
			ModPrefs.Instance.IniWriteValue(section, name, value);
		}

		public static void SetBool(string section, string name, bool value)
		{
			ModPrefs.Instance.IniWriteValue(section, name, value ? "1" : "0");
		}
	}
}
